==> babel-preset-react-scope-style-0.0.3.tgz: package/esm/plugins/inject-scope.js <==
"use strict";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var hash = require('hash-sum');

var options = require('../options');

var _require = require('../utils'),
    ScopeName = _require.ScopeName,
    ClassNames = _require.ClassNames,
    expr2str = _require.expr2str,
    isFunction = _require.isFunction;

function createScopePrefix(scopeNamespace) {
  return "x-".concat(scopeNamespace ? "".concat(scopeNamespace, "-") : '');
}

function createScopeId(filename, scopeNamespace) {
  if (options.pkg) filename = "".concat(options.pkg.name, "!").concat(filename);
  return "".concat(createScopePrefix(scopeNamespace)).concat(hash(filename.replace(/\\/g, '/')));
}

var excluedTags = ['template', 'slot'];

module.exports = function (_ref) {
  var t = _ref.types,
      template = _ref.template;
  var scope = Boolean(options.scope);
  var scopeAttrs = options.scopeAttrs;
  var scopeFn = options.scopeFn || (isFunction(options.scope) ? options.scope : null);
  var scopeNamespace = options.scopeNamespace || (typeof options.scope === 'string' ? options.scope : '');
  var scopePrefix = createScopePrefix(scopeNamespace);
  var classAttrs = options.classAttrs;
  var scopeAll = options.scopeAll;
  return {
    visitor: {
      Program: {
        enter: function enter(path, _ref2) {
          var filename = _ref2.file.opts.filename;
          var ctx = {
            globalId: '',
            scopeId: scopeAll ? createScopeId(filename, scopeNamespace, scopePrefix) : '',
            filename: filename,
            regx: options.scopeRegx,
            handled: []
          };
          path.traverse({
            ImportDeclaration: function ImportDeclaration(path) {
              var source = path.node.source.value;

              var _ref3 = source.match(this.regx) || [],
                  _ref4 = _slicedToArray(_ref3, 3),
                  matched = _ref4[0],
                  scoped = _ref4[2];

              if (!matched) return;
              var scopeId = '';
              var isGlobal = scoped === '?global';

              if (scope) {
                if (isGlobal) scopeId = scopePrefix;else if (scoped === '?scoped') scopeId = this.scopeId || createScopeId(filename, scopeNamespace, scopePrefix);
              }

              if (!scopeId) {
                if (scopeFn) {
                  var _file = source.replace(this.regx, function (match, p1) {
                    return scopeFn(p1, '', {
                      filename: filename,
                      source: source,
                      scopeId: ''
                    });
                  });

                  if (_file) path.node.source.value = _file;
                }

                return;
              }

              if (!isGlobal) this.scopeId = scopeId;
              var query = "?".concat(ScopeName, "&scoped=true").concat(isGlobal ? '&global=true' : '', "&id=").concat(scopeId);
              var file = source.replace(this.regx, function (match, p1) {
                if (!scopeFn) return p1 + query;
                return scopeFn(p1, query, {
                  filename: filename,
                  source: source,
                  scopeId: scopeId,
                  global: isGlobal
                });
              });
              if (file) path.node.source.value = file;
            }
          }, ctx);

          function traverseClassAttrs(path, attrName) {
            var classAttr = path.node.openingElement.attributes.find(function (attr) {
              return attr.name && expr2str(attr.name) === attrName;
            });

            if (classAttr) {
              if (t.isStringLiteral(classAttr.value)) {
                classAttr.value = t.stringLiteral("".concat(this.scopeId, " ").concat(classAttr.value.value));
              } else if (t.isJSXExpressionContainer(classAttr.value)) {
                var expr = classAttr.value.expression;

                var updator = function updator(v) {
                  return classAttr.value.expression = v;
                };

                if (t.isCallExpression(expr) && expr2str(expr.callee) === ClassNames) {
                  expr = classAttr.value.expression.arguments[0];

                  updator = function updator(v) {
                    return classAttr.value.expression.arguments[0] = v;
                  };
                }

                updator(template('[$SCOPEID$,$SOURCE$]')({
                  $SCOPEID$: t.stringLiteral(this.scopeId),
                  $SOURCE$: expr
                }).expression);
              }
            } else if (attrName === 'className') {
              path.get('openingElement').unshiftContainer('attributes', t.jsxAttribute(t.jsxIdentifier(attrName), t.stringLiteral(this.scopeId)));
            }
          }

          if (scopeAttrs && ctx.scopeId) {
            path.traverse({
              JSXElement: function JSXElement(path) {
                var _this = this;

                var tagName = expr2str(path.node.openingElement.name);
                if (!tagName || excluedTags.includes(tagName)) return;
                classAttrs.forEach(function (attrName) {
                  return traverseClassAttrs.call(_this, path, attrName);
                });
              }
            }, ctx);
          }
        }
      }
    }
  };
};

==> babel-preset-react-scope-style-0.0.7.tgz: package/esm/plugins/inject-scope.js <==
"use strict";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var hash = require('hash-sum');

var options = require('../options');

var _require = require('../utils'),
    ScopeName = _require.ScopeName,
    ClassNames = _require.ClassNames,
    expr2str = _require.expr2str,
    isFunction = _require.isFunction;

function createScopePrefix(scopeNamespace) {
  return "v-".concat(scopeNamespace ? "".concat(scopeNamespace, "-") : '');
}

function createScopeId(filename, scopeNamespace) {
  if (options.pkg) filename = "".concat(options.pkg.name, "!").concat(filename);
  return "".concat(createScopePrefix(scopeNamespace)).concat(hash(filename.replace(/\\/g, '/')));
}

var excluedTags = ['template', 'slot'];

module.exports = function (_ref) {
  var t = _ref.types,
      template = _ref.template;
  var scope = Boolean(options.scope);
  var scopeAttrs = options.scopeAttrs;
  var scopeFn = options.scopeFn || (isFunction(options.scope) ? options.scope : null);
  var scopeNamespace = options.scopeNamespace || (typeof options.scope === 'string' ? options.scope : '');
  var scopePrefix = createScopePrefix(scopeNamespace);
  var classAttrs = options.classAttrs;
  var scopeAll = options.scopeAll;
  return {
    visitor: {
      Program: {
        enter: function enter(path, _ref2) {
          var filename = _ref2.file.opts.filename;
          var ctx = {
            globalId: '',
            scopeId: scopeAll ? createScopeId(filename, scopeNamespace, scopePrefix) : '',
            filename: filename,
            regx: options.scopeRegx,
            handled: []
          };
          path.traverse({
            ImportDeclaration: function ImportDeclaration(path) {
              var source = path.node.source.value;

              var _ref3 = source.match(this.regx) || [],
                  _ref4 = _slicedToArray(_ref3, 3),
                  matched = _ref4[0],
                  scoped = _ref4[2];

              if (!matched) return;
              var scopeId = '';
              var isGlobal = scoped === '?global';

              if (scope) {
                if (isGlobal) scopeId = scopePrefix;else if (scoped === '?scoped') scopeId = this.scopeId || createScopeId(filename, scopeNamespace, scopePrefix);
              }

              if (!scopeId) {
                if (scopeFn) {
                  var _file = source.replace(this.regx, function (match, p1) {
                    return scopeFn(p1, '', {
                      filename: filename,
                      source: source,
                      scopeId: ''
                    });
                  });

                  if (_file) path.node.source.value = _file;
                }

                return;
              }

              if (!isGlobal) this.scopeId = scopeId;
              var query = "?".concat(ScopeName, "&scoped=true").concat(isGlobal ? '&global=true' : '', "&id=").concat(scopeId);
              var file = source.replace(this.regx, function (match, p1) {
                if (!scopeFn) return p1 + query;
                return scopeFn(p1, query, {
                  filename: filename,
                  source: source,
                  scopeId: scopeId,
                  global: isGlobal
                });
              });
              if (file) path.node.source.value = file;
            }
          }, ctx);

          function traverseClassAttrs(path, attrName) {
            var classAttr = path.node.openingElement.attributes.find(function (attr) {
              return attr.name && expr2str(attr.name) === attrName;
            });

            if (classAttr) {
              if (t.isStringLiteral(classAttr.value)) {
                classAttr.value = t.stringLiteral("".concat(this.scopeId, " ").concat(classAttr.value.value));
              } else if (t.isJSXExpressionContainer(classAttr.value)) {
                var expr = classAttr.value.expression;

                var updator = function updator(v) {
                  return classAttr.value.expression = v;
                };

                if (t.isCallExpression(expr) && expr2str(expr.callee) === ClassNames) {
                  expr = classAttr.value.expression.arguments[0];

                  updator = function updator(v) {
                    return classAttr.value.expression.arguments[0] = v;
                  };
                }

                updator(template('[$SCOPEID$,$SOURCE$]')({
                  $SCOPEID$: t.stringLiteral(this.scopeId),
                  $SOURCE$: expr
                }).expression);
              }
            } else if (attrName === 'className') {
              path.get('openingElement').unshiftContainer('attributes', t.jsxAttribute(t.jsxIdentifier(attrName), t.stringLiteral(this.scopeId)));
            }
          }

          if (scopeAttrs && ctx.scopeId) {
            path.traverse({
              JSXElement: function JSXElement(path) {
                var _this = this;

                var tagName = expr2str(path.node.openingElement.name);
                if (!tagName || excluedTags.includes(tagName)) return;
                classAttrs.forEach(function (attrName) {
                  return traverseClassAttrs.call(_this, path, attrName);
                });
              }
            }, ctx);
          }
        }
      }
    }
  };
};
